@@ -14,6 +14,8 @@ class CalcType(Enum):
     UVVIS = 11
     MO = 12
 
+    OPTFREQ = 20
+
 ATOMIC_NUMBER = {}
 ATOMIC_SYMBOL = {}
 LOWERCASE_ATOMIC_SYMBOLS = {}
@@ -63,8 +65,18 @@ STR_TYPES = {#TODO: more synonyms
         "mo": CalcType.MO,
         "mo calc": CalcType.MO,
         "mo calculation": CalcType.MO,
+        "optfreq": CalcType.OPTFREQ,
+        "opt_freq": CalcType.OPTFREQ,
+        "opt-freq": CalcType.OPTFREQ,
+        "opt+freq": CalcType.OPTFREQ,
         }
 
+INV_STR_TYPES = {}
+for cmd, t in STR_TYPES.items():
+    if t in INV_STR_TYPES.keys():
+        INV_STR_TYPES[t].append(cmd)
+    else:
+        INV_STR_TYPES[t] = [cmd]
 
 SPECIFICATIONS = {
     'gaussian': {
@@ -162,7 +174,7 @@ THEORY_LEVELS = {
 
 SYN_SOFTWARE = {
     'gaussian': ['g16', 'gaussian16', 'gaussian 16'],
-    'orca': [],
+    'orca': ['orca 5', 'orca5'],
         }
 
 SYN_SOLVENTS = {
@@ -506,6 +518,46 @@ SYN_METHODS = {
         'dlpno-qcisd(t)': ['dlpno-qcisdt', 'dlpnoqcisdt'],
     }
 
+
+
+# Gaussian allows the combination of exchange and correlation functionals
+# without using any special keyword.
+
+EXCHANGE_FUNCTIONALS = {
+        's': 'S',
+        'xa': 'XA',
+        'b': 'B',
+        'pw91': 'PW91',
+        'mpw': 'mPW',
+        'g96': 'G96',
+        'pbe': 'PBE',
+        'o': 'O',
+        'tpss': 'TPSS',
+        'revtpss': 'RevTPSS',
+        'brx': 'BRx',
+        'pkzb': 'PKZB',
+        'wpbeh': 'wPBEh',
+        'pbeh': 'PBEh',
+}
+
+CORRELATION_FUNCTIONALS = {
+        'vwn': 'VWN',
+        'vwn5': 'VWN5',
+        'lyp': 'LYP',
+        'pl': 'PL',
+        'p86': 'P86',
+        'pw91': 'PW91',
+        'b95': 'B95',
+        'pbe': 'PBE',
+        'tpss': 'TPSS',
+        'revtpss': 'RevTPSS',
+        'kcis': 'KCIS',
+        'brc': 'BRC',
+        'pkzb': 'PKZB',
+        'vp86': 'VP86',
+        'v5lyp': 'V5LYP',
+}
+
 SYN_BASIS_SETS = {
         'sto-3g': [],
 
@@ -1903,4 +1955,103 @@ SOFTWARE_SOLVENTS = {
                 },
 }
 
+# The two lists below use the "absolute" method identifications.
+# See SYN_METHODS for the full list of names and their synonyms.
+
+# These lists contain all the functionals with D3 parameters developed
+# by the Grimme group, which are not software specific. As such, the
+# parameters might not be available in every QM package (although it could).
+
+# Some functionals were not found in the list of known functionals or synonyms.
+# These are indicated with the question mark.
+FUNCTIONALS_WITH_DISPERSION_PARAMETERS = {
+        'd3': [
+                'b1b95',
+                'b2gp-plyp',
+                'b3lyp',
+                'b97-d',
+                'bhlyp', # BHandHLYP?
+                'blyp',
+                'bp86', # ?
+                'bpbe', # HISSbPBE?
+                'mpwlyp',
+                'pbe',
+                'pbe0',
+                'pw6b95',
+                'pwb6k', # ?
+                'revpbe',
+                'tpss',
+                'tpss0',
+                'tpssh',
+                'bop', # ?
+                'mpw1b95', # ?
+                'mpwb1k', # ?
+                'olyp',
+                'opbe',
+                'otpss', # ?
+                'pbe38', # ?
+                'pbesol', # ?
+                'revssb', # ?
+                'ssb', # ?
+                'b3pw91', # ?
+                'bmk',
+                'cam-b3lyp',
+                'lcwpbe', # ?
+                'm052x',
+                'm05',
+                'm062x',
+                'm06hf',
+                'm06l',
+                'm06',
+                'hcth120', # ?
+                'b2plyp',
+                'dsdblyp', # ?
+                'ptpss', # ?
+                'pwpb95',
+                'revpbe0', # ?
+                'revpbe38', # ?
+                'rpw86pbe',
+            ],
+        'd3bj': [
+                '1b95',
+                'b2gp-plyp',
+                'b3pw91', # ?
+                'bhlyp', # ?
+                'bmk',
+                'bop', # ?
+                'bpbe', # ?
+                'cam-b3lyp',
+                'lcwpbe', # ?
+                'mpw1b95', # ?
+                'mpwb1k', # ?
+                'mpwlyp',
+                'olyp',
+                'opbe',
+                'otpss', # ?
+                'pbe38', # ?
+                'pbesol', # ?
+                'ptpss', # ?
+                'pwb6k', # ?
+                'revssb', # ?
+                'ssb', # ?
+                'tpssh',
+                'hcth120', # ?
+                'b2plyp',
+                'b3lyp',
+                'b97-d',
+                'blyp',
+                'bp86', # ?
+                'dsdblyp', # ?
+                'pbe0',
+                'pbe',
+                'pw6b95',
+                'pwpb95',
+                'revpbe0', # ?
+                'revpbe38', # ?
+                'revpbe',
+                'rpw86pbe',
+                'tpss0',
+                'tpss',
+            ],
+}
 
