@@ -7,7 +7,7 @@ class GaussianTests(InputTests):
         params = { 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'AM1',
                 'charge': '-1',
@@ -35,7 +35,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'HF',
                 'basis_set': '3-21G',
@@ -64,7 +64,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'HF',
                 'basis_set': '3-21G',
@@ -95,7 +95,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Single-Point Energy',
-                'in_file': 'I.xyz',
+                'file': 'I.xyz',
                 'software': 'Gaussian',
                 'method': 'HF',
                 'basis_set': '3-21G',
@@ -132,7 +132,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'HF',
                 'basis_set': '3-21G',
@@ -166,7 +166,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'HF',
                 'basis_set': '3-21G',
@@ -198,7 +198,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'HF',
                 'basis_set': '3-21G',
@@ -232,7 +232,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'HF',
                 'basis_set': '3-21G',
@@ -264,7 +264,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'HF',
                 'basis_set': '3-21G',
@@ -296,7 +296,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'HF',
                 'basis_set': '3-21G',
@@ -328,7 +328,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'HF',
                 'basis_set': '3-21G',
@@ -345,7 +345,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'M06-2X',
                 'basis_set': 'Def2-SVP',
@@ -374,7 +374,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'M06-2X',
                 'basis_set': 'Def2-SVP',
@@ -404,7 +404,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'M06-2X',
                 'basis_set': 'Def2-SVP',
@@ -436,7 +436,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Geometrical Optimisation',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'M06-2X',
                 'basis_set': 'Def2-SVP',
@@ -467,7 +467,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Geometrical Optimisation',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'M06-2X',
                 'basis_set': 'Def2-SVP',
@@ -497,7 +497,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Geometrical Optimisation',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'M06-2X',
                 'basis_set': 'Def2-SVP',
@@ -527,7 +527,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Geometrical Optimisation',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'AM1',
                 'charge': '-1',
@@ -555,7 +555,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Geometrical Optimisation',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'HF',
                 'basis_set': '3-21G',
@@ -584,7 +584,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Geometrical Optimisation',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'charge': '-1',
                 'method': 'B3LYP',
@@ -614,7 +614,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Frequency Calculation',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'AM1',
                 'charge': '-1',
@@ -642,7 +642,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Frequency Calculation',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'HF',
                 'basis_set': '3-21G',
@@ -671,7 +671,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Frequency Calculation',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'charge': '-1',
                 'method': 'B3LYP',
@@ -700,7 +700,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Constrained Optimisation',
-                'in_file': 'ethanol.xyz',
+                'file': 'ethanol.xyz',
                 'software': 'Gaussian',
                 'charge': '0',
                 'method': 'B3LYP',
@@ -740,7 +740,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Constrained Optimisation',
-                'in_file': 'ethanol.xyz',
+                'file': 'ethanol.xyz',
                 'software': 'Gaussian',
                 'charge': '0',
                 'method': 'B3LYP',
@@ -780,7 +780,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Constrained Optimisation',
-                'in_file': 'ethanol.xyz',
+                'file': 'ethanol.xyz',
                 'software': 'Gaussian',
                 'charge': '0',
                 'method': 'B3LYP',
@@ -820,7 +820,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Constrained Optimisation',
-                'in_file': 'ethanol.xyz',
+                'file': 'ethanol.xyz',
                 'software': 'Gaussian',
                 'charge': '0',
                 'method': 'B3LYP',
@@ -860,7 +860,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Constrained Optimisation',
-                'in_file': 'ethanol.xyz',
+                'file': 'ethanol.xyz',
                 'software': 'Gaussian',
                 'charge': '0',
                 'method': 'B3LYP',
@@ -900,7 +900,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Constrained Optimisation',
-                'in_file': 'ethanol.xyz',
+                'file': 'ethanol.xyz',
                 'software': 'Gaussian',
                 'charge': '0',
                 'method': 'B3LYP',
@@ -940,7 +940,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Constrained Optimisation',
-                'in_file': 'ethanol.xyz',
+                'file': 'ethanol.xyz',
                 'software': 'Gaussian',
                 'charge': '0',
                 'method': 'B3LYP',
@@ -980,7 +980,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Constrained Optimisation',
-                'in_file': 'ethanol.xyz',
+                'file': 'ethanol.xyz',
                 'software': 'Gaussian',
                 'charge': '0',
                 'method': 'B3LYP',
@@ -996,7 +996,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Constrained Optimisation',
-                'in_file': 'ethanol.xyz',
+                'file': 'ethanol.xyz',
                 'software': 'Gaussian',
                 'charge': '0',
                 'method': '',
@@ -1012,7 +1012,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Constrained Optimisation',
-                'in_file': 'ethanol.xyz',
+                'file': 'ethanol.xyz',
                 'software': 'Gaussian',
                 'charge': '0',
                 'method': 'B3LYP',
@@ -1052,7 +1052,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Constrained Optimisation',
-                'in_file': 'ethanol.xyz',
+                'file': 'ethanol.xyz',
                 'software': 'Gaussian',
                 'charge': '0',
                 'method': 'B3LYP',
@@ -1093,7 +1093,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'NMR Prediction',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'charge': '-1',
                 'method': 'B3LYP',
@@ -1122,7 +1122,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'TS Optimisation',
-                'in_file': 'mini_ts.xyz',
+                'file': 'mini_ts.xyz',
                 'software': 'Gaussian',
                 'charge': '0',
                 'method': 'B3LYP',
@@ -1154,7 +1154,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'TS Optimisation',
-                'in_file': 'mini_ts.xyz',
+                'file': 'mini_ts.xyz',
                 'software': 'Gaussian',
                 'charge': '0',
                 'method': 'B3LYP',
@@ -1189,7 +1189,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'UV-Vis Calculation',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'M06-2X',
                 'basis_set': 'Def2-SVP',
@@ -1218,7 +1218,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Geometrical Optimisation',
-                'in_file': 'ethanol.xyz',
+                'file': 'ethanol.xyz',
                 'software': 'Gaussian',
                 'charge': '0',
                 'method': 'B3LYP',
@@ -1299,7 +1299,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Geometrical Optimisation',
-                'in_file': 'ethanol.xyz',
+                'file': 'ethanol.xyz',
                 'software': 'Gaussian',
                 'charge': '0',
                 'method': 'B3LYP',
@@ -1337,7 +1337,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Geometrical Optimisation',
-                'in_file': 'Ph2I_cation.xyz',
+                'file': 'Ph2I_cation.xyz',
                 'software': 'Gaussian',
                 'charge': '+1',
                 'method': 'B3LYP',
@@ -1488,7 +1488,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Geometrical Optimisation',
-                'in_file': 'Ph2I_cation.xyz',
+                'file': 'Ph2I_cation.xyz',
                 'software': 'Gaussian',
                 'charge': '+1',
                 'method': 'B3LYP',
@@ -1687,7 +1687,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Geometrical Optimisation',
-                'in_file': 'AuI.xyz',
+                'file': 'AuI.xyz',
                 'software': 'Gaussian',
                 'charge': '0',
                 'method': 'B3LYP',
@@ -1878,7 +1878,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'M06-2X',
                 'basis_set': 'Def2-SVP',
@@ -1909,7 +1909,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'M06-2X',
                 'basis_set': 'Def2-SVP',
@@ -1923,7 +1923,7 @@ class GaussianTests(InputTests):
         %chk=calc.chk
         %nproc=8
         %mem=10000MB
-        #p sp M062X/Def2SVP scf(tight,xqc)
+        #p sp M062X/Def2SVP scf(tight, xqc)
 
         File created by ccinput
 
@@ -1933,14 +1933,14 @@ class GaussianTests(InputTests):
         """
 
         self.assertTrue(self.is_equivalent(REF, inp.input_file))
-        self.assertEqual(inp.confirmed_specifications.strip(), 'scf(tight,xqc)')
+        self.assertEqual(inp.confirmed_specifications.strip(), 'scf(tight, xqc)')
 
     def test_multiple_global_specification2(self):
         params = {
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'M06-2X',
                 'basis_set': 'Def2-SVP',
@@ -1954,7 +1954,7 @@ class GaussianTests(InputTests):
         %chk=calc.chk
         %nproc=8
         %mem=10000MB
-        #p sp M062X/Def2SVP scf(tight,xqc)
+        #p sp M062X/Def2SVP scf(tight, xqc)
 
         File created by ccinput
 
@@ -1964,14 +1964,14 @@ class GaussianTests(InputTests):
         """
 
         self.assertTrue(self.is_equivalent(REF, inp.input_file))
-        self.assertEqual(inp.confirmed_specifications.strip(), 'scf(tight,xqc)')
+        self.assertEqual(inp.confirmed_specifications.strip(), 'scf(tight, xqc)')
 
     def test_multiple_global_specification3(self):
         params = {
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'M06-2X',
                 'basis_set': 'Def2-SVP',
@@ -1985,7 +1985,7 @@ class GaussianTests(InputTests):
         %chk=calc.chk
         %nproc=8
         %mem=10000MB
-        #p sp M062X/Def2SVP scf(tight,xqc)
+        #p sp M062X/Def2SVP scf(tight, xqc)
 
         File created by ccinput
 
@@ -1995,7 +1995,7 @@ class GaussianTests(InputTests):
         """
 
         self.assertTrue(self.is_equivalent(REF, inp.input_file))
-        self.assertEqual(inp.confirmed_specifications.strip(), 'scf(tight,xqc)')
+        self.assertEqual(inp.confirmed_specifications.strip(), 'scf(tight, xqc)')
 
 
     def test_cmd_specification(self):
@@ -2003,7 +2003,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Geometrical Optimisation',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'M06-2X',
                 'basis_set': 'Def2-SVP',
@@ -2033,7 +2033,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Geometrical Optimisation',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'M06-2X',
                 'basis_set': 'Def2-SVP',
@@ -2063,7 +2063,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Geometrical Optimisation',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'M06-2X',
                 'basis_set': 'Def2-SVP',
@@ -2093,7 +2093,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Geometrical Optimisation',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'M06-2X',
                 'basis_set': 'Def2-SVP',
@@ -2123,7 +2123,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Geometrical Optimisation',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'M06-2X',
                 'basis_set': 'Def2-SVP',
@@ -2153,7 +2153,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Geometrical Optimisation',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'M06-2X',
                 'basis_set': 'Def2-SVP',
@@ -2169,7 +2169,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'Geometrical Optimisation',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'M06-2X',
                 'basis_set': 'Def2-SVP',
@@ -2200,7 +2200,7 @@ class GaussianTests(InputTests):
                 'mem': '10000MB',
                 'type': 'Constrained Optimisation',
                 'constraints': 'Freeze/1_2_3;',
-                'in_file': 'CH4.xyz',
+                'file': 'CH4.xyz',
                 'software': 'Gaussian',
                 'method': 'M06-2X',
                 'basis_set': 'Def2-SVP',
@@ -2217,7 +2217,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'UV-Vis Calculation',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'M06-2X',
                 'basis_set': 'Def2-SVP',
@@ -2247,7 +2247,7 @@ class GaussianTests(InputTests):
                 'nproc': 1,
                 'mem': '10000MB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'HF',
                 'basis_set': '3-21G',
@@ -2276,7 +2276,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000 m',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'HF',
                 'basis_set': '3-21G',
@@ -2305,7 +2305,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10GB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'HF',
                 'basis_set': '3-21G',
@@ -2334,7 +2334,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10GB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'pkzbpkzb',
                 'basis_set': '3-21G',
@@ -2363,7 +2363,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10GB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'pBeHpkzb',
                 'basis_set': '3-21G',
@@ -2392,7 +2392,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10GB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'rHF',
                 'basis_set': '3-21G',
@@ -2421,7 +2421,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10GB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'uHF',
                 'basis_set': '3-21G',
@@ -2450,7 +2450,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10GB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'iHF',
                 'basis_set': '3-21G',
@@ -2479,7 +2479,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10GB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'uM062x',
                 'basis_set': '3-21G',
@@ -2508,7 +2508,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10GB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'rPBE0',
                 'basis_set': '3-21G',
@@ -2537,7 +2537,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'opt+freq',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'AM1',
                 'charge': '-1',
@@ -2549,7 +2549,7 @@ class GaussianTests(InputTests):
         %chk=calc.chk
         %nproc=8
         %mem=10000MB
-        #p opt AM1 freq
+        #p freq opt AM1
 
         File created by ccinput
 
@@ -2565,7 +2565,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10000MB',
                 'type': 'optfreq',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'AM1',
                 'charge': '-1',
@@ -2577,7 +2577,36 @@ class GaussianTests(InputTests):
         %chk=calc.chk
         %nproc=8
         %mem=10000MB
-        #p opt AM1 freq
+        #p freq opt AM1
+
+        File created by ccinput
+
+        -1 1
+        Cl 0.0 0.0 0.0
+
+        """
+
+        self.assertTrue(self.is_equivalent(REF, inp.input_file))
+
+    def test_opt_freq_spec(self):
+        params = {
+                'nproc': 8,
+                'mem': '10000MB',
+                'type': 'opt+freq',
+                'file': 'Cl.xyz',
+                'software': 'Gaussian',
+                'method': 'AM1',
+                'charge': '-1',
+                'specifications': 'freq(noraman)',
+                }
+
+        inp = self.generate_calculation(**params)
+
+        REF = """
+        %chk=calc.chk
+        %nproc=8
+        %mem=10000MB
+        #p opt freq(noraman) AM1
 
         File created by ccinput
 
@@ -2593,7 +2622,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10GB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'M062X',
                 'basis_set': '3-21G',
@@ -2607,7 +2636,7 @@ class GaussianTests(InputTests):
         %chk=calc.chk
         %nproc=8
         %mem=10000MB
-        #p sp M062X/3-21G EmpiricalDispersion=GD3
+        #p sp M062X/3-21G EmpiricalDispersion(GD3)
 
         File created by ccinput
 
@@ -2623,7 +2652,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10GB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'PBE0',
                 'basis_set': '3-21G',
@@ -2637,7 +2666,7 @@ class GaussianTests(InputTests):
         %chk=calc.chk
         %nproc=8
         %mem=10000MB
-        #p sp PBE1PBE/3-21G EmpiricalDispersion=GD3BJ
+        #p sp PBE1PBE/3-21G EmpiricalDispersion(GD3BJ)
 
         File created by ccinput
 
@@ -2653,7 +2682,7 @@ class GaussianTests(InputTests):
                 'nproc': 8,
                 'mem': '10GB',
                 'type': 'Single-Point Energy',
-                'in_file': 'Cl.xyz',
+                'file': 'Cl.xyz',
                 'software': 'Gaussian',
                 'method': 'PBE0',
                 'basis_set': '3-21G',
@@ -2665,3 +2694,227 @@ class GaussianTests(InputTests):
         with self.assertRaises(InvalidParameter):
             self.generate_calculation(**params)
 
+    def test_smd_custom_radius(self):
+        params = {
+                'nproc': 8,
+                'mem': '10000MB',
+                'type': 'Single-Point Energy',
+                'file': 'I.xyz',
+                'software': 'Gaussian',
+                'method': 'HF',
+                'basis_set': '3-21G',
+                'charge': '-1',
+                'solvent': 'Chloroform',
+                'custom_solvation_radii': 'Cl=1.00',
+                'solvation_model': 'SMD',
+                }
+
+        inp = self.generate_calculation(**params)
+
+        REF = """
+        %chk=calc.chk
+        %nproc=8
+        %mem=10000MB
+        #p sp HF/3-21G SCRF(SMD, Solvent=chloroform, Read)
+
+        File created by ccinput
+
+        -1 1
+        I 0.0 0.0 0.0
+
+        modifysph
+
+        Cl 1.00
+
+        """
+
+        self.assertTrue(self.is_equivalent(REF, inp.input_file))
+
+    def test_smd_custom_radii(self):
+        params = {
+                'nproc': 8,
+                'mem': '10000MB',
+                'type': 'Single-Point Energy',
+                'file': 'I.xyz',
+                'software': 'Gaussian',
+                'method': 'HF',
+                'basis_set': '3-21G',
+                'charge': '-1',
+                'solvent': 'Chloroform',
+                'custom_solvation_radii': 'Cl=1.00;Br=2.00;',
+                'solvation_model': 'SMD',
+                }
+
+        inp = self.generate_calculation(**params)
+
+        REF = """
+        %chk=calc.chk
+        %nproc=8
+        %mem=10000MB
+        #p sp HF/3-21G SCRF(SMD, Solvent=chloroform, Read)
+
+        File created by ccinput
+
+        -1 1
+        I 0.0 0.0 0.0
+
+        modifysph
+
+        Cl 1.00
+        Br 2.00
+
+        """
+
+        self.assertTrue(self.is_equivalent(REF, inp.input_file))
+
+    def test_smd_custom_radius_and_smd18(self):
+        params = {
+                'nproc': 8,
+                'mem': '10000MB',
+                'type': 'Single-Point Energy',
+                'file': 'I.xyz',
+                'software': 'Gaussian',
+                'method': 'HF',
+                'basis_set': '3-21G',
+                'charge': '-1',
+                'solvent': 'Chloroform',
+                'custom_solvation_radii': 'Cl=1.00',
+                'solvation_model': 'SMD',
+                'solvation_radii': 'SMD18',
+                }
+
+        inp = self.generate_calculation(**params)
+
+        REF = """
+        %chk=calc.chk
+        %nproc=8
+        %mem=10000MB
+        #p sp HF/3-21G SCRF(SMD, Solvent=chloroform, Read)
+
+        File created by ccinput
+
+        -1 1
+        I 0.0 0.0 0.0
+
+        modifysph
+
+        Br 2.60
+        I 2.74
+        Cl 1.00
+
+        """
+
+        self.assertTrue(self.is_equivalent(REF, inp.input_file))
+
+    def test_pcm_custom_radius(self):
+        params = {
+                'nproc': 8,
+                'mem': '10000MB',
+                'type': 'Single-Point Energy',
+                'file': 'I.xyz',
+                'software': 'Gaussian',
+                'method': 'HF',
+                'basis_set': '3-21G',
+                'charge': '-1',
+                'solvent': 'Chloroform',
+                'custom_solvation_radii': 'Cl=1.00',
+                'solvation_model': 'PCM',
+                }
+
+        inp = self.generate_calculation(**params)
+
+        REF = """
+        %chk=calc.chk
+        %nproc=8
+        %mem=10000MB
+        #p sp HF/3-21G SCRF(PCM, Solvent=chloroform, Read)
+
+        File created by ccinput
+
+        -1 1
+        I 0.0 0.0 0.0
+
+        modifysph
+
+        Cl 1.00
+
+        """
+
+        self.assertTrue(self.is_equivalent(REF, inp.input_file))
+
+    def test_pcm_custom_radius_and_bondi(self):
+        params = {
+                'nproc': 8,
+                'mem': '10000MB',
+                'type': 'Single-Point Energy',
+                'file': 'I.xyz',
+                'software': 'Gaussian',
+                'method': 'HF',
+                'basis_set': '3-21G',
+                'charge': '-1',
+                'solvent': 'Chloroform',
+                'solvation_radii': 'Bondi',
+                'custom_solvation_radii': 'Cl=1.00',
+                'solvation_model': 'PCM',
+                }
+
+        inp = self.generate_calculation(**params)
+
+        REF = """
+        %chk=calc.chk
+        %nproc=8
+        %mem=10000MB
+        #p sp HF/3-21G SCRF(PCM, Solvent=chloroform, Read)
+
+        File created by ccinput
+
+        -1 1
+        I 0.0 0.0 0.0
+
+        Radii=bondi
+        modifysph
+
+        Cl 1.00
+
+        """
+
+        self.assertTrue(self.is_equivalent(REF, inp.input_file))
+
+    def test_pcm_custom_radii_and_bondi(self):
+        params = {
+                'nproc': 8,
+                'mem': '10000MB',
+                'type': 'Single-Point Energy',
+                'file': 'I.xyz',
+                'software': 'Gaussian',
+                'method': 'HF',
+                'basis_set': '3-21G',
+                'charge': '-1',
+                'solvent': 'Chloroform',
+                'solvation_radii': 'Bondi',
+                'custom_solvation_radii': 'Cl=1.00;C=2.00;',
+                'solvation_model': 'PCM',
+                }
+
+        inp = self.generate_calculation(**params)
+
+        REF = """
+        %chk=calc.chk
+        %nproc=8
+        %mem=10000MB
+        #p sp HF/3-21G SCRF(PCM, Solvent=chloroform, Read)
+
+        File created by ccinput
+
+        -1 1
+        I 0.0 0.0 0.0
+
+        Radii=bondi
+        modifysph
+
+        Cl 1.00
+        C 2.00
+
+        """
+
+        self.assertTrue(self.is_equivalent(REF, inp.input_file))
