@@ -5,7 +5,7 @@ from ccinput.wrapper import generate_calculation
 
 class InputTests(TestCase):
     def generate_calculation(self, **params):
-        params['in_file'] = os.path.join('/'.join(__file__.split('/')[:-1]), "structures/", params['in_file'])
+        params['file'] = os.path.join('/'.join(__file__.split('/')[:-1]), "structures/", params['file'])
         return generate_calculation(**params)
 
     def is_equivalent(self, ref, res):
